@@ -1,9 +1,10 @@
 
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns, url
 
 
 urlpatterns = patterns("mezzanine.generic.views",
     url("^admin_keywords_submit/$", "admin_keywords_submit",
         name="admin_keywords_submit"),
     url("^rating/$", "rating", name="rating"),
+    url("^comment/$", "comment", name="comment"),
 )
